(annotate doc obj)Inputs: [doc :- spec/Operation obj]
Attaches swagger documentation to an object
Inputs: [doc :- spec/Operation obj] Attaches swagger documentation to an object
(coerce-request)(coerce-request f)Creates an interceptor that coerces the params for the selected route, according to the route's swagger documentation. A coercion function f that acceps the route params schema and a request and return a request can be supplied. The default implementation throws if any coercion error occurs.
Creates an interceptor that coerces the params for the selected route, according to the route's swagger documentation. A coercion function f that acceps the route params schema and a request and return a request can be supplied. The default implementation throws if any coercion error occurs.
(doc m)Adds metatata m to a swagger route
Adds metatata m to a swagger route
(validate-response)(validate-response f)Creates an interceptor that validates the response for the selected route, according to the route's swagger documentation. A validation function f that accepts the route response schema and a response and return a response can be supplied. The default implementation throws if a validation error occours.
Creates an interceptor that validates the response for the selected route, according to the route's swagger documentation. A validation function f that accepts the route response schema and a response and return a response can be supplied. The default implementation throws if a validation error occours.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |